@@ -1,5 +1,6 @@
-Err_exp_scale <-function(X,vec=vec,exp=exp){
+Err_exp_scale <-function(X,EO){
+  vec <- colnames(X)
   l_vec <- length(vec)
   cmb1 <- combinations(n=l_vec, r=3, v=vec, set=FALSE, repeats.allowed=FALSE)
-  return(sum(exp[cmb1]))
+  return(sum(EO[cmb1]))
 }
\ No newline at end of file
